#ifndef OIDC_CJSON_H
#define OIDC_CJSON_H

#ifndef USE_CJSON_SO
#include "cJSON/cJSON.h"
#else
#include <cjson/cJSON.h>
#endif /* USE_CJSON_SO */

#endif /* OIDC_CJSON_H */
